pub struct ExtractedSource {
pub root: PathBuf,
/* private fields */
}Expand description
An extracted crate source tree in a temporary directory.
Owns a TempDir that is cleaned up on drop. root is the actual crate root
(the single top-level directory inside the archive, where Cargo.toml lives).
Fields
root: PathBufThe path to the crate root inside the tempdir.