pub fn fetch_github_tree(
client: &Client,
repo: &GitHubRepo,
tag: &str,
) -> Result<Vec<String>>Expand description
Fetch the file listing of a GitHub repo at a given tag using the Trees API. Returns a list of file paths relative to the repo root.